# Supported Boards & Micro Controller Units

## AdaFruit Boards

* [AdaFruit ATmega32U4] (./cores/cosa/Cosa/Board/AdaFruit/ATmega32U4.hh)

## Anarduino Boards

* [Anarduino MiniWireless] (./cores/cosa/Cosa/Board/Anarduino/MiniWireless.hh)

## Arduino Boards

* [Arduino Diecimila] (./cores/cosa/Cosa/Board/Arduino/Diecimila.hh)
* [Arduino Duemilanove] (./cores/cosa/Cosa/Board/Arduino/Duemilanove.hh)
* [Arduino Leonardo] (./cores/cosa/Cosa/Board/Arduino/Leonardo.hh)
* [Arduino Mega 1280] (./cores/cosa/Cosa/Board/Arduino/Mega.hh)
* [Arduino Mega 2560] (./cores/cosa/Cosa/Board/Arduino/Mega.hh)
* [Arduino Micro] (./cores/cosa/Cosa/Board/Arduino/Micro.hh)
* [Arduino Nano] (./cores/cosa/Cosa/Board/Arduino/Nano.hh)
* [Arduino Pro Micro] (./cores/cosa/Cosa/Board/Arduino/Pro_Micro.hh)
* [Arduino Pro Mini] (./cores/cosa/Cosa/Board/Arduino/Pro_Mini.hh)
* [Arduino Uno] (./cores/cosa/Cosa/Board/Arduino/Uno.hh)

## Breadboards

* Breadboard ([ATtinyX4] (./cores/cosa/Cosa/Board/Arduino/ATtinyX4.hh), [ATtinyX5] (./cores/cosa/Cosa/Board/Arduino/ATtinyX5.hh), [ATtinyX61] (./cores/cosa/Cosa/Board/Arduino/ATtinyX61.hh), [ATmega328] (./cores/cosa/Cosa/Board/Arduino/ATmega328P.hh), [ATmega1284] (./cores/cosa/Cosa/Board/Arduino/ATmega1284P.hh))

## ITEAD Studio Boards

* [ITEAD Studio IBoard] (./cores/cosa/Cosa/Board/ITEADStudio/IBoard.hh)

## LilyPad Boards

* [LilyPad Arduino] (./cores/cosa/Cosa/Board/Arduino/LilyPad.hh)
* [LilyPad Arduino USB] (./cores/cosa/Cosa/Board/Arduino/LilyPad_USB.hh)

## LowPowerLab Boards

* [LowPowerLab Moteino] (./cores/cosa/Cosa/Board/LowPowerLab/Moteino.hh)
* [LowPowerLab Moteino Mega] (./cores/cosa/Cosa/Board/LowPowerLab/Moteino_Mega.hh)

## Pinoccio Boards

* [Pinoccio Scout] (./cores/cosa/Cosa/Board/Pinoccio/Scout.hh)

## Microduino Boards

* [Microduino-Core] (./cores/cosa/Cosa/Board/Microduino/Core.hh)
* [Microduino-Core32u4] (./cores/cosa/Cosa/Board/Microduino/Core32U4.hh)
* [Microduino-Core+] (./cores/cosa/Cosa/Board/Microduino/Core_Plus.hh)

## PJRC Tennsy Boards

* [PJRC Teensy 2.0] (./cores/cosa/Cosa/Board/PJRC/Teensy_2_0.hh)
* [PJRC Teensy++ 2.0] (./cores/cosa/Cosa/Board/PJRC/Teensypp_2_0.hh)

## Wicked Device Boards

* [Wicked Device WildFire V3] (./cores/cosa/Cosa/Board/WickedDevice/WildFire.hh)
